@@ -1,6 +1,6 @@
 #pragma once
 
-#include "../../desktop/WLSurface.hpp"
+#include "../../desktop/view/WLSurface.hpp"
 #include "../../macros.hpp"
 #include "../../helpers/math/Math.hpp"
 #include "../../helpers/signal/Signal.hpp"
@@ -22,17 +22,17 @@ class CInputPopup {
     void                   onCommit();
 
   private:
-    SP<CWLSurface>          queryOwner();
-    void                    updateBox();
+    SP<Desktop::View::CWLSurface> queryOwner();
+    void                          updateBox();
 
-    void                    onDestroy();
-    void                    onMap();
-    void                    onUnmap();
+    void                          onDestroy();
+    void                          onMap();
+    void                          onUnmap();
 
-    WP<CInputMethodPopupV2> m_popup;
-    SP<CWLSurface>          m_surface;
-    CBox                    m_lastBoxLocal;
-    MONITORID               m_lastMonitor = MONITOR_INVALID;
+    WP<CInputMethodPopupV2>       m_popup;
+    SP<Desktop::View::CWLSurface> m_surface;
+    CBox                          m_lastBoxLocal;
+    MONITORID                     m_lastMonitor = MONITOR_INVALID;
 
     struct {
         CHyprSignalListener map;
