@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "386376400119dd46a767c9f8c8791fd22c7b6e61"
-#define GIT_BRANCH         "v0.52.2"
-#define GIT_COMMIT_MESSAGE "[gha] Nix: update inputs"
-#define GIT_COMMIT_DATE    "Wed Dec 3 22:59:30 2025"
+#define GIT_COMMIT_HASH    "ea444c35bb23b6e34505ab6753e069de7801cc25"
+#define GIT_BRANCH         "v0.53.0"
+#define GIT_COMMIT_MESSAGE "version: bump to 0.53.0"
+#define GIT_COMMIT_DATE    "Mon Dec 29 15:21:36 2025"
 #define GIT_DIRTY          "clean"
-#define GIT_TAG            "v0.52.2"
-#define GIT_COMMITS        "6581"
+#define GIT_TAG            "v0.53.0"
+#define GIT_COMMITS        "6756"
 
 #define AQUAMARINE_VERSION "0.10.0"
 // clang-format off
